@@ -12,12 +12,8 @@ zfs-tpm-list -H "$DSET" | while read -r _ backend keystatus coherent; do
 		exit 1
 	}
 
-	case "$backend" in
-		TPM1.X) unlock='zfs-tpm1x-load-key'; deps='trousers.service' ;;
-		TPM2)   unlock='zfs-tpm2-load-key';  deps=                   ;;
-		*)      unlock=;                     deps=                   ;;
-	esac
-
+	unlock=; deps=
+	read -r unlock deps 2>/dev/null < "/usr/share/tzpfms/$backend"
 	command -v "$unlock" >/dev/null || {
 		printf "%s\n" "${0##*/}[$$]: $DSET: unknown tzpfms back-end $backend." >&2
 		exit # fall through, maybe there's another handler
