@@ -1,10 +1,6 @@
 /* SPDX-License-Identifier: MIT */
 
 
-#include <libzfs.h>
-// #include <sys/zio_crypt.h>
-#define WRAPPING_KEY_LEN 32
-
 #include <stdio.h>
 
 #include "../fd.hpp"
@@ -81,12 +77,11 @@ int main(int argc, char ** argv) {
 			    }));
 
 			    uint8_t wrap_key[WRAPPING_KEY_LEN];
-			    TPMI_DH_PERSISTENT persistent_handle{};
-
 			    TRY_MAIN(tpm2_generate_rand(tpm2_ctx, wrap_key, sizeof(wrap_key)));
 			    if(backup)
 				    TRY_MAIN(write_exact(backup, wrap_key, sizeof(wrap_key), 0400));
 
+			    TPMI_DH_PERSISTENT persistent_handle{};
 			    TRY_MAIN(tpm2_seal(zfs_get_name(dataset), tpm2_ctx, tpm2_session, persistent_handle, pcrs, allow_PCR_or_pass, wrap_key, sizeof(wrap_key)));
 			    bool ok = false;  // Try to free the persistent handle if we're unsuccessful in actually using it later on
 			    quickscope_wrapper persistent_clearer{[&] {
