@@ -1,10 +1,6 @@
 /* SPDX-License-Identifier: MIT */
 
 
-#include <libzfs.h>
-// #include <sys/zio_crypt.h>
-#define WRAPPING_KEY_LEN 32
-
 #include <stdio.h>
 
 #include "../fd.hpp"
