@@ -4,26 +4,22 @@
 #pragma once
 
 
-#include "common.hpp"
 #include <stdint.h>
+#include <stdio.h>
 #include <unistd.h>
 
 
 template <class F>
 int with_stdin_at(int fd, F && what) {
 	auto stdin_saved = dup(0);
-	quickscope_wrapper stdin_saved_deleter{[=] { close(stdin_saved); }};
 
 	dup2(fd, 0);
-
 	clearerr(stdin);
-	if(int ret = what()) {
-		dup2(stdin_saved, 0);
-		return ret;
-	}
+	int ret = what();
 
 	dup2(stdin_saved, 0);
-	return 0;
+	close(stdin_saved);
+	return ret;
 }
 
 /// with_len may not exceed pipe capacity (64k by default)
