@@ -97,9 +97,11 @@ int tpm1x_parse_pcrs(char * arg, uint32_t *& pcrs, size_t & pcrs_len) {
 	for(arg = strtok_r(arg, ", ", &sv); arg; arg = strtok_r(nullptr, ", ", &sv)) {
 		uint32_t pcr;
 		if(!parse_uint(arg, pcr))
-			return fprintf(stderr, "PCR %s: %s\n", arg, strerror(errno)), __LINE__;
+			// user-supplied parameter, errno
+			return fprintf(stderr, gettext("PCR %s: %s\n"), arg, strerror(errno)), __LINE__;
 		if(pcr >= 230)
-			return fprintf(stderr, "PCR %s: too large (max 229).\n", arg), __LINE__;
+			// user-supplied parameter
+			return fprintf(stderr, gettext("PCR %s: too large (max 229).\n"), arg), __LINE__;
 
 		auto idx = std::upper_bound(pcrs, pcrs + pcrs_len, pcr) - pcrs;
 		if(!idx || pcrs[idx - 1] != pcr) {
